@@ -44,7 +44,7 @@ get_n_actions (AtkAction *action)
 	return 1;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 get_description (AtkAction *action, gint i)
 {
 	if (i == 0)
@@ -53,7 +53,7 @@ get_description (AtkAction *action, gint i)
 	return NULL;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 action_get_name (AtkAction *action, gint i)
 {
 	if (i == 0)
@@ -68,11 +68,7 @@ do_action (AtkAction * action, gint i)
 	GtkWidget *widget;
 	gboolean return_value = TRUE;
 
-#if GTK_CHECK_VERSION(2,21,0)
 	widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (action));
-#else
-	widget = GTK_ACCESSIBLE (action)->widget;
-#endif
 
 	if (widget == NULL) {
 	/*
@@ -155,7 +151,7 @@ gtk_html_a11y_get_type (void)
 static void
 gtk_html_a11y_finalize (GObject *obj)
 {
-        G_OBJECT_CLASS (parent_class)->finalize (obj);
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -247,7 +243,7 @@ gtk_html_a11y_ref_child (AtkObject *accessible, gint index)
 	return accessible_child;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 gtk_html_a11y_get_name (AtkObject *obj)
 {
 	if (obj->name != NULL) {
@@ -283,10 +279,10 @@ gtk_html_a11y_get_focus_object (GtkWidget * widget)
 {
 	GtkHTML * html;
 	HTMLObject * htmlobj = NULL;
-        AtkObject *obj = NULL;
+	AtkObject *obj = NULL;
 	gint offset;
 
-	html = GTK_HTML(widget);
+	html = GTK_HTML (widget);
 
 	g_return_val_if_fail (html && html->engine, NULL);
 
@@ -304,9 +300,9 @@ gtk_html_a11y_get_focus_object (GtkWidget * widget)
 static AtkObject * gtk_html_a11y_focus_object = NULL;
 
 static void
-gtk_html_a11y_grab_focus_cb(GtkWidget * widget)
+gtk_html_a11y_grab_focus_cb (GtkWidget * widget)
 {
-        AtkObject *focus_object, *obj, *clue;
+	AtkObject *focus_object, *obj, *clue;
 
 	focus_object = gtk_html_a11y_get_focus_object (widget);
 	if (focus_object == NULL)
@@ -314,8 +310,8 @@ gtk_html_a11y_grab_focus_cb(GtkWidget * widget)
 
 	obj = gtk_widget_get_accessible (widget);
 
-	clue = html_utils_get_accessible(GTK_HTML(widget)->engine->clue, obj);
-	atk_object_set_parent(clue, obj);
+	clue = html_utils_get_accessible (GTK_HTML (widget)->engine->clue, obj);
+	atk_object_set_parent (clue, obj);
 
 	gtk_html_a11y_focus_object = focus_object;
 	atk_focus_tracker_notify (focus_object);
@@ -333,10 +329,10 @@ gtk_html_a11y_cursor_changed_cb (GtkWidget *widget)
 		gtk_html_a11y_focus_object = focus_object;
 		atk_focus_tracker_notify (focus_object);
 	} else {
-		if (G_IS_HTML_A11Y_TEXT(focus_object)) {
+		if (G_IS_HTML_A11Y_TEXT (focus_object)) {
 			gint offset;
 
-			offset = (GTK_HTML(widget))->engine->cursor->offset;
+			offset = (GTK_HTML (widget))->engine->cursor->offset;
 			g_signal_emit_by_name(focus_object, "text_caret_moved",offset);
 		}
 	}
@@ -357,7 +353,7 @@ gtk_html_a11y_insert_object_cb (GtkWidget * widget, gint pos, gint len)
 		atk_focus_tracker_notify (a11y);
 	}
 
-	if (G_IS_HTML_A11Y_TEXT(a11y)) {
+	if (G_IS_HTML_A11Y_TEXT (a11y)) {
 		g_signal_emit_by_name (a11y, "text_changed::insert", cursor->offset - len, len);
 
 	}
@@ -376,7 +372,7 @@ gtk_html_a11y_delete_object_cb (GtkWidget * widget, gint pos, gint len)
 		atk_focus_tracker_notify (a11y);
 	}
 
-	if (G_IS_HTML_A11Y_TEXT(a11y)) {
+	if (G_IS_HTML_A11Y_TEXT (a11y)) {
 		g_signal_emit_by_name (a11y, "text_changed::delete", pos, len);
 	}
 }
@@ -384,8 +380,10 @@ gtk_html_a11y_delete_object_cb (GtkWidget * widget, gint pos, gint len)
 AtkObject*
 gtk_html_a11y_new (GtkWidget *widget)
 {
+	GtkHTML *html;
 	GObject *object;
-	AtkObject *accessible, *focus_object;
+	AtkObject *accessible;
+	AtkObject *focus_object = NULL;
 
 	g_return_val_if_fail (GTK_IS_HTML (widget), NULL);
 
@@ -399,21 +397,21 @@ gtk_html_a11y_new (GtkWidget *widget)
 			G_CALLBACK (gtk_html_a11y_grab_focus_cb),
 			NULL);
 	g_signal_connect (widget, "cursor_changed",
-			G_CALLBACK(gtk_html_a11y_cursor_changed_cb),
+			G_CALLBACK (gtk_html_a11y_cursor_changed_cb),
 			NULL);
 	g_signal_connect_after (widget, "object_inserted",
-			G_CALLBACK(gtk_html_a11y_insert_object_cb),
+			G_CALLBACK (gtk_html_a11y_insert_object_cb),
 			NULL);
 	g_signal_connect_after (widget, "object_delete",
-			G_CALLBACK(gtk_html_a11y_delete_object_cb),
+			G_CALLBACK (gtk_html_a11y_delete_object_cb),
 			NULL);
 
-	if (GTK_HTML(widget)->engine->clue)
-		html_utils_get_accessible(GTK_HTML(widget)->engine->clue, accessible);
+	html = GTK_HTML (widget);
 
-	/* printf ("created new gtkhtml accessible object\n"); */
-
-	focus_object = gtk_html_a11y_get_focus_object (widget);
+	if (html->engine != NULL && html->engine->clue != NULL) {
+		html_utils_get_accessible (html->engine->clue, accessible);
+		focus_object = gtk_html_a11y_get_focus_object (widget);
+	}
 
 	if (focus_object && gtk_html_a11y_focus_object != focus_object) {
 		gtk_html_a11y_focus_object = focus_object;
