@@ -267,7 +267,7 @@ op_helper (HTMLObject *self, HTMLEngine *e, GList *from, GList *to, GList *left,
 	if (!from && prev_flow_in_cluevs (self)) {
 		(*len) ++;
 		/* if (cut)
-		   e->cursor->position --; */
+		   e->cursor->position--; */
 	}
 	if (cut)
 		html_clue_remove_text_slaves (HTML_CLUE (self));
@@ -391,9 +391,9 @@ merge (HTMLObject *self, HTMLObject *with, HTMLEngine *e, GList **left, GList **
 			cf2->item_type = cf1->item_type;
 
 			update_item_number (self, e);
-			cf1->item_number --;
+			cf1->item_number--;
 			update_item_number (with, e);
-			cf1->item_number ++;
+			cf1->item_number++;
 
 			if (cf2_next_relative)
 				update_item_number (cf2_next_relative, e);
@@ -450,7 +450,7 @@ need_blockquote_padding  (HTMLClueFlow *flow, HTMLClueFlow *prev)
 	if (i < flow->levels->len || flow->levels->len == 0) {
 		if (i < prev->levels->len)
 			return TRUE;
-                else
+		else
 			return FALSE;
 	}
 
@@ -463,7 +463,7 @@ need_blockquote_padding  (HTMLClueFlow *flow, HTMLClueFlow *prev)
 	while (i > 0) {
 		HTMLListType type;
 
-		type = prev->levels->data [prev->levels->len - i];
+		type = prev->levels->data[prev->levels->len - i];
 
 		if (is_blockquote (type)) {
 			return TRUE;
@@ -821,35 +821,35 @@ update_top_height (HTMLObject *begin, HTMLObject *end, gint *a, gint *d, gint *h
 inline HTMLHAlignType
 html_clueflow_get_halignment (HTMLClueFlow *flow)
 {
-        g_return_val_if_fail (flow != NULL, HTML_HALIGN_NONE);
+	g_return_val_if_fail (flow != NULL, HTML_HALIGN_NONE);
 
-        if (HTML_CLUE (flow)->halign == HTML_HALIGN_NONE) {
-                HTMLHAlignType halign;
+	if (HTML_CLUE (flow)->halign == HTML_HALIGN_NONE) {
+		HTMLHAlignType halign;
 
-                if (HTML_OBJECT (flow)->parent && HTML_IS_TABLE_CELL (HTML_OBJECT (flow)->parent))
-                        halign = HTML_CLUE (HTML_OBJECT (flow)->parent)->halign == HTML_HALIGN_NONE
-                                ? HTML_TABLE_CELL (HTML_OBJECT (flow)->parent)->heading ? HTML_HALIGN_CENTER : HTML_HALIGN_NONE
-                                : HTML_CLUE (HTML_OBJECT (flow)->parent)->halign;
-                else
-                        halign = HTML_CLUE (HTML_OBJECT (flow)->parent)->halign;
+		if (HTML_OBJECT (flow)->parent && HTML_IS_TABLE_CELL (HTML_OBJECT (flow)->parent))
+			halign = HTML_CLUE (HTML_OBJECT (flow)->parent)->halign == HTML_HALIGN_NONE
+				? HTML_TABLE_CELL (HTML_OBJECT (flow)->parent)->heading ? HTML_HALIGN_CENTER : HTML_HALIGN_NONE
+				: HTML_CLUE (HTML_OBJECT (flow)->parent)->halign;
+		else
+			halign = HTML_CLUE (HTML_OBJECT (flow)->parent)->halign;
 
-                if (halign == HTML_HALIGN_NONE) {
-                        switch (html_object_get_direction (HTML_OBJECT (flow))) {
-                        case HTML_DIRECTION_LTR:
-                                halign = HTML_HALIGN_LEFT;
-                                break;
-                        case HTML_DIRECTION_RTL:
-                                halign = HTML_HALIGN_RIGHT;
-                                break;
-                        default:
-                                break;
-                        }
-                }
+		if (halign == HTML_HALIGN_NONE) {
+			switch (html_object_get_direction (HTML_OBJECT (flow))) {
+			case HTML_DIRECTION_LTR:
+				halign = HTML_HALIGN_LEFT;
+				break;
+			case HTML_DIRECTION_RTL:
+				halign = HTML_HALIGN_RIGHT;
+				break;
+			default:
+				break;
+			}
+		}
 
-                return halign;
+		return halign;
 
-        } else
-                return HTML_CLUE (flow)->halign;
+	} else
+		return HTML_CLUE (flow)->halign;
 }
 
 static inline void
@@ -1143,19 +1143,19 @@ get_roman_value (gint value, gboolean lower)
 		if (r != 0) {
 			if (r < 4) {
 				for (; r; r--)
-					g_string_prepend_c (str, base [b] + add);
+					g_string_prepend_c (str, base[b] + add);
 			} else if (r == 4) {
-				g_string_prepend_c (str, base [b + 1] + add);
-				g_string_prepend_c (str, base [b] + add);
+				g_string_prepend_c (str, base[b + 1] + add);
+				g_string_prepend_c (str, base[b] + add);
 			} else if (r == 5) {
-				g_string_prepend_c (str, base [b + 1] + add);
+				g_string_prepend_c (str, base[b + 1] + add);
 			} else if (r < 9) {
 				for (; r > 5; r--)
-					g_string_prepend_c (str, base [b] + add);
-				g_string_prepend_c (str, base [b + 1] + add);
+					g_string_prepend_c (str, base[b] + add);
+				g_string_prepend_c (str, base[b + 1] + add);
 			} else if (r == 9) {
-				g_string_prepend_c (str, base [b + 2] + add);
-				g_string_prepend_c (str, base [b] + add);
+				g_string_prepend_c (str, base[b + 2] + add);
+				g_string_prepend_c (str, base[b] + add);
 			}
 		}
 	}
@@ -1174,9 +1174,9 @@ get_item_marker_str (HTMLClueFlow *flow, gboolean ascii_only)
 	if (type == HTML_LIST_TYPE_BLOCKQUOTE && flow->levels->len > 0) {
 		gint i;
 
-		for (i = flow->levels->len - 1; i >= 0; i --) {
-			if (flow->levels->data [i] != HTML_LIST_TYPE_BLOCKQUOTE) {
-				type = flow->levels->data [i];
+		for (i = flow->levels->len - 1; i >= 0; i--) {
+			if (flow->levels->data[i] != HTML_LIST_TYPE_BLOCKQUOTE) {
+				type = flow->levels->data[i];
 				break;
 			}
 		}
@@ -1490,7 +1490,7 @@ write_indent (HTMLEngineSaveState *state, gint level)
 	while (level > 0) {
 		if (!html_engine_save_output_string (state, "    "))
 			return FALSE;
-		level --;
+		level--;
 	}
 
 	return TRUE;
@@ -1673,6 +1673,7 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 	HTMLClueFlow *prev = NULL;
 	HTMLHAlignType halign;
 	const gchar *br_str = "<BR>\n";
+	gboolean has_div_tag = FALSE;
 
 	if (HTML_IS_CLUEFLOW (HTML_OBJECT (self)->next))
 		next = HTML_CLUEFLOW (HTML_OBJECT (self)->next);
@@ -1727,7 +1728,8 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 
 	halign = HTML_CLUE (self)->halign;
 	/* Alignment tag.  */
-	if (halign != HTML_HALIGN_NONE && halign != HTML_HALIGN_LEFT) {
+	has_div_tag = halign != HTML_HALIGN_NONE && halign != HTML_HALIGN_LEFT;
+	if (has_div_tag) {
 		if (!html_engine_save_output_string
 		    (state, "<DIV ALIGN=%s>",
 		     html_engine_save_get_paragraph_align (html_alignment_to_paragraph (halign))))
@@ -1742,19 +1744,19 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 		return FALSE;
 
 	/* Close alignment tag.  */
-	if (halign != HTML_HALIGN_NONE && halign != HTML_HALIGN_LEFT) {
+	if (has_div_tag) {
 		if (!html_engine_save_output_string (state, "</DIV>"))
 			return FALSE;
 	}
 
 	if (is_item (self)) {
-		if (next && is_levels_equal (self, next) && !is_item (next) && !html_clueflow_contains_table (self)) {
+		if (!has_div_tag && next && is_levels_equal (self, next) && !is_item (next) && !html_clueflow_contains_table (self)) {
 			if (!html_engine_save_output_string (state, "%s", br_str))
 				return FALSE;
 		} else if (!html_engine_save_output_string (state, "\n"))
 			return FALSE;
 	} else if (is_levels_equal (self, next) && self->style == next->style) {
-		if (self->style != HTML_CLUEFLOW_STYLE_PRE && !html_clueflow_contains_table (self)) {
+		if (!has_div_tag && self->style != HTML_CLUEFLOW_STYLE_PRE && !html_clueflow_contains_table (self)) {
 			if (!html_engine_save_output_string (state, "%s", br_str))
 				return FALSE;
 		} else {
@@ -1765,7 +1767,7 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 		const gchar *end = get_start_tag (self);
 
 		if (self->style != HTML_CLUEFLOW_STYLE_PRE) {
-			if ((!html_clueflow_contains_table (self) && !end && next && self->style == next->style) || html_clueflow_is_empty (self)) {
+			if (!has_div_tag && ((!html_clueflow_contains_table (self) && !end && next && self->style == next->style) || html_clueflow_is_empty (self))) {
 				if (!html_engine_save_output_string (state, "%s", br_str))
 					return FALSE;
 			} else {
@@ -1883,8 +1885,8 @@ plain_padding (HTMLClueFlow *flow, GString *out, gboolean firstline)
 	pad_string = g_string_new ("");
 
 #define APPEND_PLAIN(w) \
-        pad_len += strlen (w); \
-        if (out) g_string_append (pad_string, w);
+	pad_len += strlen (w); \
+	if (out) g_string_append (pad_string, w);
 
 	if (flow->levels->len) {
 		for (i = 0; i < flow->levels->len; i++) {
@@ -1919,7 +1921,7 @@ static void
 append_selection_string (HTMLObject *self,
 			 GString *buffer)
 {
-        (*HTML_OBJECT_CLASS (parent_class)->append_selection_string) (self, buffer);
+	(*HTML_OBJECT_CLASS (parent_class)->append_selection_string) (self, buffer);
 
 	if (self->selected) {
 		g_string_append_c (buffer, '\n');
@@ -2018,23 +2020,23 @@ save_plain (HTMLObject *self,
 			lattrs = g_new (PangoLogAttr, slen + 1);
 			n_items = g_list_length (items_list);
 			items = g_new (PangoItem *, n_items);
-			for (i = 0, cur = items_list; i < n_items; i ++, cur = cur->next)
-				items [i] = (PangoItem *) cur->data;
+			for (i = 0, cur = items_list; i < n_items; i++, cur = cur->next)
+				items[i] = (PangoItem *) cur->data;
 
 			offset = 0;
-			for (i = 0; i < n_items; i ++) {
+			for (i = 0; i < n_items; i++) {
 				PangoItem tmp_item;
 				gint start_offset;
 
 				start_offset = offset;
-				offset += items [i]->num_chars;
-				tmp_item = *items [i];
+				offset += items[i]->num_chars;
+				tmp_item = *items[i];
 				while (i < n_items - 1) {
-					if (tmp_item.analysis.lang_engine == items [i + 1]->analysis.lang_engine) {
-						tmp_item.length += items [i + 1]->length;
-						tmp_item.num_chars += items [i + 1]->num_chars;
-						offset += items [i + 1]->num_chars;
-						i ++;
+					if (tmp_item.analysis.lang_engine == items[i + 1]->analysis.lang_engine) {
+						tmp_item.length += items[i + 1]->length;
+						tmp_item.num_chars += items[i + 1]->num_chars;
+						offset += items[i + 1]->num_chars;
+						i++;
 					} else
 						break;
 				}
@@ -2045,8 +2047,8 @@ save_plain (HTMLObject *self,
 			html_text_remove_unwanted_line_breaks ((gchar *) s, slen, lattrs);
 
 			g_list_free (items_list);
-			for (i = 0; i < n_items; i ++)
-				pango_item_free (items [i]);
+			for (i = 0; i < n_items; i++)
+				pango_item_free (items[i]);
 			g_free (items);
 			pango_attr_list_unref (attrs);
 
@@ -2067,12 +2069,12 @@ save_plain (HTMLObject *self,
 						wmax = clen + utf8_length_in_width ((gchar *) s, len, max_width);
 						wl = wmax;
 
-						if (lattrs [wl].is_white) {
+						if (lattrs[wl].is_white) {
 
-							while (lattrs [wl].is_white && wl < slen)
-								wl ++;
+							while (lattrs[wl].is_white && wl < slen)
+								wl++;
 
-							if (wl < slen && html_text_is_line_break (lattrs [wl]))
+							if (wl < slen && html_text_is_line_break (lattrs[wl]))
 								look_backward = FALSE;
 							else
 								wl = wmax;
@@ -2080,16 +2082,16 @@ save_plain (HTMLObject *self,
 
 						if (look_backward) {
 							while (wl > 0) {
-								if (html_text_is_line_break (lattrs [wl]))
+								if (html_text_is_line_break (lattrs[wl]))
 									break;
-								wl --;
+								wl--;
 							}
 						}
 
-						if (wl > clen && wl < slen && html_text_is_line_break (lattrs [wl])) {
+						if (wl > clen && wl < slen && html_text_is_line_break (lattrs[wl])) {
 							wi = MIN (wl, wmax);
-							while (wi > clen && lattrs [wi - 1].is_white)
-								wi --;
+							while (wi > clen && lattrs[wi - 1].is_white)
+								wi--;
 							len = wi - clen;
 							width = utf8_width ((gchar *) s, len);
 							skip = wl - wi;
@@ -2133,7 +2135,7 @@ save_plain (HTMLObject *self,
 
 				if (*s == '\n') {
 					s++;
-					clen ++;
+					clen++;
 				}
 
 				g_string_append_c (out, '\n');
@@ -2262,7 +2264,7 @@ search_text (HTMLObject **beg, HTMLSearch *info)
 
 	if (text_bytes > 0) {
 		par = (guchar *) g_new (gchar, text_bytes + 1);
-		par [text_bytes] = 0;
+		par[text_bytes] = 0;
 
 		pp = (info->forward) ? par : par + text_bytes;
 
@@ -2288,9 +2290,9 @@ search_text (HTMLObject **beg, HTMLSearch *info)
 		eq_bytes = 0;
 		if (info->found) {
 			if (info->start_pos > 0)
-				index = ((guchar *)g_utf8_offset_to_pointer ((gchar *) par, info->start_pos + ((info->forward) ? 0 : -1))) - par;
+				index = ((guchar *) g_utf8_offset_to_pointer ((gchar *) par, info->start_pos + ((info->forward) ? 0 : -1))) - par;
 			else
-				index = info->forward ? ((guchar *)g_utf8_offset_to_pointer ((gchar *) par, info->start_pos) - par) : -1;
+				index = info->forward ? ((guchar *) g_utf8_offset_to_pointer ((gchar *) par, info->start_pos) - par) : -1;
 		} else {
 			index = (info->forward) ? 0 : text_bytes;
 		}
@@ -2361,12 +2363,12 @@ search_text (HTMLObject **beg, HTMLSearch *info)
 					unicode_info = g_utf8_get_char (info->text + eq_bytes);
 					unicode_par = g_utf8_get_char ((gchar *) par + index);
 					if (!info->case_sensitive) {
-                                             unicode_info = g_unichar_toupper (unicode_info);
+					     unicode_info = g_unichar_toupper (unicode_info);
 					     unicode_par  = g_unichar_toupper (unicode_par);
 					}
 
 					if (unicode_info == unicode_par) {
-						eq_bytes += (guchar *)g_utf8_next_char (par + index) - par - index;
+						eq_bytes += (guchar *) g_utf8_next_char (par + index) - par - index;
 
 						if (eq_bytes == info->text_bytes) {
 							/* The above par + index is always at the beginning of the last character matched */
@@ -2943,7 +2945,7 @@ get_text (HTMLClue *clue, HTMLInterval *i)
 
 	bytes        = get_text_bytes (clue, i);
 	ct           = text = g_malloc (bytes + 1);
-	text [bytes] = 0;
+	text[bytes] = 0;
 
 	obj = html_interval_get_head (i, HTML_OBJECT (clue));
 	while (obj) {
